==> 1.0.2.tar.gz: lib/nessmediametadataretriever.dart <==

import 'dart:async';
import 'dart:io';
import 'dart:convert';
import 'dart:typed_data';
import 'package:flutter/services.dart';

var kChannel = const MethodChannel('nessmediametadataretriever');

class NessMetadataRetriever {
  static Future<Metadata> fromFile(File file) async {
    return Metadata.fromMap(await kChannel
        .invokeMethod('NessMetadataRetriever', {'filePath': file.path}));
  }
}
class Metadata {
  final String? title;
  final List<String>? artists;
  final String? album;
  final String? albumArtist;
  final int? duration;
  final Uint8List? albumArt;

  const Metadata(
      {this.title,
        this.artists,
        this.album,
        this.albumArtist,
        this.duration,
        this.albumArt});

  static fromMap(dynamic map) => Metadata(
    title: map['metadata']['trackName'],
    artists: map['metadata']['trackArtistNames'] != null
        ? map['metadata']['trackArtistNames'].split('/')
        : null,
    album: map['metadata']['albumName'],
    albumArtist: map['metadata']['albumArtistName'],
    duration: parse(map['metadata']['trackDuration']),
    albumArt: map['albumArt'],
  );

  Map<String, dynamic> toMap() => {
    'title': title,
    'artists': artists,
    'album': album,
    'albumArtist': albumArtist,
    'duration': duration,
  };

  @override
  String toString() => JsonEncoder.withIndent('    ').convert(toMap());
}

int? parse(String? string) {
  if (string == null) return null;
  try {
    try {
      return int.parse(string);
    } catch (exception) {
      return int.parse(string.split('/').first);
    }
  } catch (exception) {}
  return null;
}

==> 1.0.3.tar.gz: lib/nessmediametadataretriever.dart <==

import 'dart:async';
import 'dart:io';
import 'dart:convert';
import 'dart:typed_data';
import 'package:flutter/services.dart';

var kChannel = const MethodChannel('nessmediametadataretriever');

class NessMetadataRetriever {
  static Future<NessMetadata> fromFile(File file) async {
    return NessMetadata.fromMap(await kChannel
        .invokeMethod('NessMetadataRetriever', {'filePath': file.path}));
  }
}
class NessMetadata {
  final String? title;
  final List<String>? artists;
  final String? album;
  final String? albumArtist;
  final int? duration;
  final String? path;
  final Uint8List? albumArt;

  const NessMetadata(
      {this.title,
        this.artists,
        this.album,
        this.albumArtist,
        this.duration,
        this.path,
        this.albumArt});

  static fromMap(dynamic map) => NessMetadata(
    title: map['metadata']['trackName'],
    artists: map['metadata']['trackArtistNames'] != null
        ? map['metadata']['trackArtistNames'].split('/')
        : null,
    album: map['metadata']['albumName'],
    albumArtist: map['metadata']['albumArtistName'],
    duration: parse(map['metadata']['trackDuration']),
    path: map['metadata']['path'],
    albumArt: map['albumArt'],
  );

  Map<String, dynamic> toMap() => {
    'title': title,
    'artists': artists,
    'album': album,
    'albumArtist': albumArtist,
    'duration': duration,
    'path': path,
    'albumArt': albumArt,
  };

  @override
  String toString() => JsonEncoder.withIndent('    ').convert(toMap());
}

int? parse(String? string) {
  if (string == null) return null;
  try {
    try {
      return int.parse(string);
    } catch (exception) {
      return int.parse(string.split('/').first);
    }
  } catch (exception) {}
  return null;
}
